@@ -149,7 +149,7 @@ class LPPLS(object):
             nothing, should plot the fit
         """
         tc, m, w, a, b, c, c1, c2 = self.coef_.values()
-        lppls_fit = [self.lppls(t, tc, m, w, a, b, c1, c2) for t in self.observations[0]]
+        lppls_fit = self.lppls(self.observations[0], tc, m, w, a, b, c1, c2)
 
         data = pd.DataFrame({
             'Time': self.observations[0],
@@ -159,16 +159,14 @@ class LPPLS(object):
         data = data.set_index('Time')
         data.plot(figsize=(14, 8))
 
-    def plot_confidence_indicators(self, res, condition_name, title):
+    def plot_confidence_indicators(self, res_df, title):
         """
         Args:
-            res (list): result from mp_compute_indicator
-            condition_name (str): the name you assigned to the filter condition in your config
+            res_df (list): result from res_df(res, condition_name)
             title (str): super title for both subplots
         Returns:
             nothing, should plot the indicator
         """
-        res_df = self.res_to_df(res, condition_name)
 
         fig, (ax1, ax2) = plt.subplots(nrows=2, ncols=1, sharex=True, figsize=(15, 12))
         fig.suptitle(title)
@@ -234,7 +232,10 @@ class LPPLS(object):
             obs_shrinking_slice = obs[:, j * increment:window_size + n_iter]
 
             # fit the model to the data and get back the params
-            tc, m, w, a, b, c, c1, c2 = self.fit(obs_shrinking_slice, max_searches, minimizer='SLSQP')
+            if self.__class__.__name__ == 'LPPLSCMAES':
+                tc, m, w, a, b, c, c1, c2 = self.fit(max_iteration=2500, pop_size=4)
+            else:
+                tc, m, w, a, b, c, c1, c2 = self.fit(obs_shrinking_slice, max_searches, minimizer='SLSQP')
 
             first = obs_shrinking_slice[0][0]
             last = obs_shrinking_slice[0][-1]
